@@ -108,7 +108,7 @@ class Crawler(Controller):
             folder_path = folder_path.rstrip('/')
             folder_path = path.expanduser(folder_path)
         else:
-            folder_path = pathlib.Path().resolve() 
+            folder_path = pathlib.Path().resolve()
             folder_path = str(folder_path)
 
         if self.app.pargs.plugin_name is not None:
@@ -139,6 +139,9 @@ class Crawler(Controller):
         elif template == 'node':
             create_boilerplate(
                 plugin_path, "node_boilerplate.jinja2", data, 'js')
+        elif template == 'brp':
+            create_boilerplate(
+                plugin_path, "php_brp_boilerplate.jinja2", data, 'php')
         else:
             create_boilerplate(
                 plugin_path, "php_boilerplate.jinja2", data, 'php')
@@ -307,13 +310,12 @@ class Crawler(Controller):
                 try:
                     app_url = f'https://appnext.grepsr.com/projects/{plugin_info["pid"]}'
                     self.app.log.info(f"App Url: {app_url}")
-                    self.app.log.info(
-                        f"Plugin: {plugin_name} deployed successfully")
                 except:
                     self.app.log.warning(
                         f"Cannot find pid in plugin, please find the project's url manually")
-                    self.app.log.info(
-                        f"Plugin: {plugin_name} deployed successfully")
+
+                self.app.log.info(
+                    f"Plugin: {plugin_name} deployed successfully")
 
     @ex(
         help="use a base plugin from: https://bitbucket.org/grepsr/vortex-plugins-services-base",
