@@ -32,14 +32,15 @@ class SDKSetup:
     def generate_autocomplete_directory(self, docker_id, dir_name):
         for service_dir in self.type_dict['paths']:
             Log.info(
-                f"Adding .autocomplete in {service_dir}")
+                f"Adding autocomplete modules in {service_dir}")
             command = f'''
                     rm -rf {service_dir}/.autocomplete && 
                     mkdir {service_dir}/.autocomplete
                 '''
 
-            command += f"""docker cp -L {docker_id}:/home/grepsr/{dir_name}/autocomplete/. {service_dir}/.autocomplete/"""
-
+            command += f"""docker cp -L {docker_id}:/home/grepsr/{dir_name}/lib {service_dir}/.autocomplete/
+            docker cp -L {docker_id}:/home/grepsr/{dir_name}/vendor {service_dir}/.autocomplete/
+            """
             system(command)
 
     def do_setup(self):
